@import url('base.css');

.jp-ReactWidget {
  color: var(--jp-ui-font-color1);
  background: var(--jp-layout-color1);
  font-size: 48px;
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
}
